/* $Id: Messages.java 1001023 2011-12-12 18:41:28Z hozawa $ */

/**
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements. See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you may not use this file except in compliance with
* the License. You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
package org.apache.manifoldcf.core.i18n;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;


public final class Messages
{
public static final String DEFAULT_BUNDLE_NAME="common";

  /** Constructor - do no instantiate
  */
  public Messages()
  {
  }
  
  public static String getString(String messageKey)
  {
    return getString(DEFAULT_BUNDLE_NAME, Locale.getDefault(), messageKey, null);
  }
  
  public static String getString(String messageKey, Object[] args)
  {
    return getString(DEFAULT_BUNDLE_NAME, Locale.getDefault(), messageKey, args);
  }
  
  public static String getString(Locale locale, String messageKey)
  {
    return getString(DEFAULT_BUNDLE_NAME, locale, messageKey, null);
  }
  
  public static String getString(Locale locale, String messageKey, Object[] args)
  {
    return getString(DEFAULT_BUNDLE_NAME, locale, messageKey, args);
  }
  
  public static String getString(String bundleName, String messageKey)
  {
    return getString(bundleName, Locale.getDefault(), messageKey, null);
  }
  
  public static String getString(String bundleName, String messageKey, Object[] args)
  {
    return getString(bundleName, Locale.getDefault(), messageKey, args);
  }
  
  public static String getString(String bundleName, Locale locale, String messageKey)
  {
    return getString(bundleName, locale, messageKey, null);
  }
  
  public static String getString(String bundleName, Locale locale, String messageKey, Object[] args)
  {
    ResourceBundle resources = null;
    String message = null;
    String formatMessage = null;
    try
    {
      resources = getBundle(bundleName, locale);
      message = resources.getString(messageKey);
      if (args != null)
       {
         formatMessage = MessageFormat.format(message, args);
       }
       else
       {
         formatMessage = message;
       }
     }
     catch (MissingResourceException e)
     {
       System.out.println("Missing resource bundle:" + messageKey);
     }
     return formatMessage;
   }
   
   protected static ResourceBundle getBundle(String bundleName, Locale locale)
   {
     String path = "org.apache.manifoldcf.core.i18n." + bundleName;
     return ResourceBundle.getBundle(path, locale);   
    }
}

